@@ -1,11 +1,10 @@
-from typing import Any, Callable, Optional, Dict
+from typing import Callable, Optional
 
 import numpy as np
 from numpy import ndarray
 
 from .form import Form, FormDict
 from ..basis import Basis
-from ...element import DiscreteField
 
 
 class LinearForm(Form):
